@@ -277,7 +277,7 @@ pref("ldap_2.servers.history.isOffline",						false);
 // default mapping of addressbook properties to ldap attributes
 pref("ldap_2.servers.default.attrmap.FirstName", "givenName");
 pref("ldap_2.servers.default.attrmap.LastName", "sn,surname");
-pref("ldap_2.servers.default.attrmap.DisplayName", "displayName,cn,commonname");
+pref("ldap_2.servers.default.attrmap.DisplayName", "cn,commonname");
 pref("ldap_2.servers.default.attrmap.NickName", "mozillaNickname,xmozillanickname");
 pref("ldap_2.servers.default.attrmap.PrimaryEmail", "mail");
 pref("ldap_2.servers.default.attrmap.SecondEmail", "mozillaSecondEmail,xmozillasecondemail");
@@ -429,6 +429,11 @@ pref("mail.server.default.max_articles", 500);
 pref("mail.server.default.notify.on", true);
 pref("mail.server.default.mark_old_read", false);
 pref("mail.server.default.empty_trash_on_exit", false);
+// 0 = Keep Dupes, leave them alone
+// 1 = delete dupes
+// 2 = Move Dupes to trash
+// 3 = Mark Dupes as Read
+pref("mail.server.default.dup_action", 0);
 
 pref("mail.server.default.using_subscription", true);
 pref("mail.server.default.dual_use_folders", true);
@@ -622,7 +627,7 @@ pref("mailnews.fakeaccount.server", "");
 
 // message display properties
 pref("mailnews.message_display.disable_remote_image", false);
-pref("mailnews.message_display.allow.plugins", true);
+pref("mailnews.message_display.allow.plugins", false);
 
 // default msg compose font prefs
 pref("msgcompose.font_face",                "");
@@ -654,9 +659,9 @@ pref("mail.standalone", false);
 // the users last used preference.
 pref("mailnews.import.text.skipfirstrecord", true);
 
-//@line 664 "/mozdisk/mozilla/mailnews/mailnews.js"
+//@line 669 "/mozdisk/101build/mozilla/mailnews/mailnews.js"
 
-//@line 667 "/mozdisk/mozilla/mailnews/mailnews.js"
+//@line 672 "/mozdisk/101build/mozilla/mailnews/mailnews.js"
 pref("mail.empty_trash", false);
 
 pref("mail.check_new_mail", true);
@@ -673,5 +678,5 @@ pref("news.show_first_unread", false);
 pref("news.sash_geometry", "");
 pref("mail.signature_date", 0);
 
-//@line 686 "/mozdisk/mozilla/mailnews/mailnews.js"
+//@line 691 "/mozdisk/101build/mozilla/mailnews/mailnews.js"
 
